@@ -1,6 +1,4 @@
 package Catmandu::Exporter::RDF;
-#ABSTRACT: serialize RDF data
-our $VERSION = '0.16'; #VERSION
 
 use namespace::clean;
 use Catmandu::Sane;
@@ -9,6 +7,8 @@ use RDF::Trine::Serializer;
 use RDF::Trine::Model;
 use RDF::aREF;
 
+our $VERSION = '0.16';
+
 with 'Catmandu::RDF';
 with 'Catmandu::Exporter';
 
@@ -50,24 +50,10 @@ sub commit {
     $self->serializer->serialize_model_to_file( $self->fh, $self->model );
 }
 
-
-
-1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
 Catmandu::Exporter::RDF - serialize RDF data
 
-=head1 VERSION
-
-version 0.16
-
 =head1 SYNOPSIS
 
     use Catmandu::Exporter::RDF;
@@ -117,6 +103,8 @@ The option C<ns> can refer to an instance of or to a constructor argument of
 L<RDF::NS>. Use a fixed date, such as "C<20130816>" to make sure your URI
 namespace prefixes are stable.
 
+=back
+
 =head1 METHODS
 
 See also L<Catmandu::Exporter>.
@@ -137,19 +125,14 @@ because RDF data is always merged to one RDF graph.
 Expand and abbreviated with L<RDF::NS>. For instance "C<dc:title>" is expanded
 to "C<http://purl.org/dc/elements/1.1/title>".
 
+=cut
+
 =head1 SEE ALSO
 
 Serialization is based on L<RDF::Trine::Serializer>.
 
-=head1 AUTHOR
-
-Jakob Voß
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Jakob Voß.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+=encoding utf8
 
 =cut
+
+1;
